# Cloud CLI

Cloud CLI is a command line tool built based on Cloud API. The owner of the software is the current user. You can use this tool to call API to manage your resources. The commands provided by this tool correspond to API.

## Features

Cloud CLI is developed based on the Go language. It parses and executes commands using API as the metadata driver, and interacts with API using HTTPS. Cloud CLI has the following features:
 * A single executable file is provided, which is green and free of installation. You can use Cloud CLI after decompressing the executable file.
 * Multiple OSs, including Linux, Windows, and macOS, are supported.
 * It is easy to expand. You can use this tool to encapsulate API and expand functions as required.

## Use

Example for using Cloud CLI
 * Lists system-level help information.
    cloud --help   
 * Lists help information about the configuration function.
    cloud configure --help   
 * Initializes configurations.
    cloud configure init   
 * Lists available APIs of a service.
    cloud ECS --help  
 * Lists parameters of an API.
    cloud ECS NovaListServers --help  
 * Calls an API after initializing configurations.
    cloud ECS NovaListServers --cli-profile=default 
 * Calls an API when the configurations are not initialized.
    cloud ECS NovaListServers --cli-region=region --cli-access-key=accessKey --cli-secret-key=secretKey  
For more information, see Cloud CLI [User Guide](https://support.hc.sbercloud.ru/en-us/usermanual/cloudcli/hcli_01.html).

## Set parameters

According to the API usage specifications, the following personal data must be configured to ensure the normal use of Cloud CLI:
 * cli-profile: name of a profile. Cloud CLI supports multiple profiles, which are distinguished by the profile name.
 * cli-mode: Cloud Cloud supports AKSK|token|agency|ecsAgency authentication. AKSK authentication is recommended.
 * [cli-project-id](https://support.hc.sbercloud.ru/en-us/usermanual/cloudcli/hcli_09_002.html): project ID.
 * [cli-region](https://support.hc.sbercloud.ru/en-us/usermanual/cloudcli/hcli_09_003.html): region.
 * [cli-x-auth-token](https://support.hc.sbercloud.ru/en-us/usermanual/cloudcli/hcli_09_004.html): access token issued by the system to an IAM user. It carries information such as the user identity and permissions.
 * [cli-domain-id](https://support.hc.sbercloud.ru/en-us/usermanual/cloudcli/hcli_09_002.html): ID of the account to which the IAM user belongs.
 * [cli-access-key](https://support.hc.sbercloud.ru/en-us/usermanual/cloudcli/hcli_09_001.html):
An access key ID (AK) is your long-term identity credential on Cloud CLOUD. You can use an AK to sign requests for calling APIs. An AK is used together with an SK to sign requests cryptographically, ensuring that the requests are secret, complete, and correct.
 * [cli-secret-key](https://support.hc.sbercloud.ru/en-us/usermanual/cloudcli/hcli_09_001.html):
A secret access key (SK) is your long-term identity credential on Cloud CLOUD. An AK is used together with an SK to sign requests cryptographically, ensuring that the requests are secret, complete, and correct.
 * [cli-security-token](https://support.hc.sbercloud.ru/en-us/usermanual/cloudcli/hcli_09_005.html): temporary token obtained by a user, which must be used together with the temporary AK/SK.
 
The preceding information is required for API authentication and is transparently transmitted to API Gateway when Cloud CLI calls APIs. You can run the configure command to encrypt the preceding information and save the encrypted information to the config.json file in the home directory of the current user. By default, the information is permanently stored unless you run the configure command to delete the information or directly delete the config.json file. You can also directly enter related configurations in the command to call an API without saving them locally.

The configuration information is stored in the following path:
 * Linux OS: /home/{Current username}/.cloud/config.json
 * Windows OS: C:\Users\{Current username}\.cloud\config.json
 * macOS: /Users/{Current username}/.cloud/config.json

## Logs

Error information generated when Cloud CLI is used is logged. If none of the parameters are specified, the default log level is error, a single log file is 20 MB, and 3 files are retained.

You can modify log configurations by setting the following parameters:
 * level: log level, which can be info, warning, or error.
 * max-file-size: maximum size (MB) of a single log file. Range: 1 to 100. Default value: 20.
 * max-file-num: the number of retained log files. The value 0 indicates that all log files are retained. Default value: 3.
 * retention-period: the number of days for retaining log files. The value 0 indicates that log files are retained permanently.

Logs are stored in the following directory:
 * Linux OS: /home/{Current username}/.cloud/log
 * Windows OS: C:\Users\{Current username}\.cloud\log
 * macOS: /Users/{Current username}/.cloud/log

## User Guide

 * [User Guide](https://support.hc.sbercloud.ru/en-us/usermanual/cloudcli/hcli_01.html)
